pub enum Response {
Show 15 variants
Pong,
ShuttingDown,
Status(DaemonStatus),
LookupResult(LookupResult),
StoreResult(StoreResult),
SessionStarted {
session_id: String,
journal_path: Option<NormalizedPath>,
},
CompileResult {
exit_code: i32,
stdout: Arc<Vec<u8>>,
stderr: Arc<Vec<u8>>,
cached: bool,
},
SessionEnded {
stats: Option<SessionStats>,
},
LinkResult {
exit_code: i32,
stdout: Arc<Vec<u8>>,
stderr: Arc<Vec<u8>>,
cached: bool,
warning: Option<String>,
},
Error {
message: String,
},
Cleared {
artifacts_removed: u64,
metadata_cleared: u64,
dep_graph_contexts_cleared: u64,
on_disk_bytes_freed: u64,
},
SessionStatsResult {
stats: Option<SessionStats>,
},
FingerprintCheckResult {
decision: String,
reason: Option<String>,
changed_files: Vec<String>,
},
FingerprintAck,
RustArtifactList {
artifacts: Vec<RustArtifactInfo>,
},
}Expand description
A response from daemon to client.
Variants
Pong
Response to Ping.
ShuttingDown
Shutdown acknowledged.
Status(DaemonStatus)
Daemon status information.
LookupResult(LookupResult)
Cache lookup result.
StoreResult(StoreResult)
Store result.
SessionStarted
Session successfully started.
Fields
journal_path: Option<NormalizedPath>Path to the per-session JSONL journal file (if journal was requested).
CompileResult
Result of a compilation request.
Fields
SessionEnded
Session ended successfully.
Fields
stats: Option<SessionStats>Per-session stats, if the session opted in to tracking.
LinkResult
Result of a link/archive request.
Fields
Error
An error occurred processing the request.
Cleared
Cache cleared successfully.
Fields
SessionStatsResult
Mid-session statistics snapshot. NOTE: Appended at end to preserve bincode variant indices.
Fields
stats: Option<SessionStats>Per-session stats, if the session exists and opted in to tracking.
FingerprintCheckResult
Result of a fingerprint check. NOTE: Appended at end to preserve bincode variant indices.
Fields
FingerprintAck
Fingerprint mark/invalidate acknowledged.
RustArtifactList
List of cached Rust artifacts. NOTE: Appended at end to preserve bincode variant indices.
Fields
artifacts: Vec<RustArtifactInfo>